#!/bin/bash

if [[ ! -w /etc/passwd ]] ; then
  echo "Only 'root' can execute this script."
  exit 1
fi

#
# Set epages environmental variables
#
[[ -f /etc/sysconfig/epages6 ]] && . /etc/sysconfig/epages6
EPAGES_PROJECT=${EPAGES_PROJECT:-$EPAGES_INSTALL_RUN_SCRIPT}
EPAGES_PROJECT=${EPAGES_PROJECT:-epages6}

void_var() {
  if [[ -n "$1" ]] ; then
    echo "Variable(s) with void value: $1"
    echo "Edit these variable(s) in /etc/sysconfig/epages6 and rerun:"
    echo "  $0"
  fi
  touch $EPAGES/Setup/mysql.ini
  exit 1
}

ls /etc/default/$EPAGES_PROJECT >/dev/null || void_var

. /etc/default/$EPAGES_PROJECT

unset QUIET
while getopts qs c ; do
  case $c in
    q) QUIET=1 ;;
  esac
done

#
# Read the connection settings from sysconfig file
#
MYSQL_SOCKET=${EPAGES_INSTALL_MYSQL_CONNECTION:-/var/lib/mysql/mysql.sock}

INI_CONFIG="$EPAGES"/bin/ini-config.sh
"$INI_CONFIG" -f /etc/default/$EPAGES_PROJECT -k EPAGES_MYSQL_CONNECTION -v \"$MYSQL_SOCKET\" -i

#
# Set the mysql connection string based on the decision if we have a socket or TCP connection here.
#
if [[ ${MYSQL_SOCKET#/} != $MYSQL_SOCKET ]] ; then
  ls -d $MYSQL_SOCKET >/dev/null || void_var EPAGES_INSTALL_MYSQL_CONNECTION
  SOCKET_CONNECTION=1
  MYSQL_CONNECTION_ARG=-S$MYSQL_SOCKET
  export MYSQL_CONN="mysql_socket=$MYSQL_SOCKET"
else
  MYSQL_HOST=${MYSQL_SOCKET%;*}
  [[ $MYSQL_HOST = $MYSQL_SOCKET ]] && MYSQL_PORT=3306 || {
    MYSQL_PORT=${MYSQL_SOCKET##*;}
  }
  MYSQL_CONNECTION_ARG="-h $MYSQL_HOST -P $MYSQL_PORT"
  unset MYSQL_SOCKET
  export MYSQL_CONN="hostname=$MYSQL_HOST;port=$MYSQL_PORT"
fi

#
# Read the backup user credentials.
#
unset MYSQL_PASS_ARG
export MYSQL_USER=${EPAGES_INSTALL_MYSQL_USER:-root}
export MYSQL_PASS=$EPAGES_INSTALL_MYSQL_PASS
MYSQL_PASS_ARG=${MYSQL_PASS:+"-p'$MYSQL_PASS'"}

[[ -n "$QUIET"  ]] && exec 2>/dev/null

#
# Test the connection based on the connection string.
#
echo exit | eval mysql $MYSQL_CONNECTION_ARG -u$MYSQL_USER $MYSQL_PASS_ARG 2>/tmp/proc.~$$~
RET=$?
if [[ $RET -ne 0 ]] ; then
  if [[ -z $MYSQL_PASS ]] ; then
    MYSQL_PASS=epages
    MYSQL_PASS_ARG=-p$MYSQL_PASS
    if echo exit | eval mysql $MYSQL_CONNECTION_ARG -u$MYSQL_USER $MYSQL_PASS_ARG 2>/dev/null ; then
      RET=0
    else
      RET=1
    fi
  fi
  if [[ $RET -ne 0 ]] ; then
    cat /tmp/proc.~$$~
    rm -f /tmp/proc.~$$~
    [[ -n "$QUIET"  ]] && void_var
    void_var EPAGES_INSTALL_MYSQL_USER/EPAGES_INSTALL_MYSQL_PASS
  fi
fi
rm -f /tmp/proc.~$$~

#
# Rewrite the database .conf files to update the datasource string and the backup user credentials.
#
$EPAGES_PERL/bin/perl -MConfig::IniFiles -MFile::Copy -e '
use DE_EPAGES::Database::API::Connection qw(EncryptDBPassword);
my $EncPasswd;
$EncPasswd = EncryptDBPassword($ENV{MYSQL_PASS}) if $ENV{MYSQL_PASS};
foreach my $Conn (qw(Site Store Backup)) {
  my $DBC = "$ENV{EPAGES_CONFIG}/Database.d/$Conn.conf";
  copy("$DBC.initial", $DBC) unless -f $DBC;
  tie %Conf, "Config::IniFiles", (-file => $DBC) or die "$DBC: $!\n";
  $Conf{Connection}{datasource} = "dbi:mysql:$ENV{MYSQL_CONN}";
  if ($Conn eq "Backup") {
    $Conf{Connection}{login} = $ENV{MYSQL_USER};
    $Conf{Connection}{encpasswd} = $EncPasswd if $ENV{MYSQL_PASS};
    delete $Conf{Connection}{passwd};
  }
  tied( %Conf )->RewriteConfig() or die "$DBC: $!\n";
  chown((getpwnam("ep_appl"))[2,3], $DBC);
}
' || void_var

rm -f $EPAGES/Setup/mysql.ini

